#L. Beauguitte, Les "artistes similaires" sur Deezer : l'exemple du black metal, 
#Espaces et radicalités, décembre 2019

rm(list=ls())

library(igraph)
link <- read.csv("liens_bm.txt", encoding="UTF-8",stringsAsFactors = FALSE)
node <- read.csv("sommets_bm.txt", encoding="UTF-8",stringsAsFactors = FALSE)

g <- graph.data.frame(link[,c(1,3)], node, directed = TRUE)

#degrés
g$degin <- degree(g, mode = c("in"))
g$degou <- degree(g, mode = c("out"))
plot(g$degin, V(g)$fans)

plot(g, vertex.label.size = 0.6, vertex.size = 6, edge.arrow.size = 0.2)

# liens entre groupes sources
g1 <- delete.vertices(g, V(g)$seed == 0)

#degrés
g1$degin <- degree(g1, mode = c("in"))
g1$degou <- degree(g1, mode = c("out"))  

plot(g1$degin, V(g1)$fans)
plot(g1$degin, g1$degou)

#liens mutuels only
E(g1)$mut <- which_mutual(g1, es = E(g1))
g1mut <- delete.edges(g1, E(g1)[mut == FALSE])

#liens asymétriques only
g1asy <- delete.edges(g1, E(g1)[mut == TRUE])

#visualisation
lay <- layout_nicely(g1)

#ensemble des liens entre groupes du corpus
plot(g1, vertex.label.size = .3, vertex.size = g1$degin/2, edge.arrow.size = .15,
     layout = lay)

par(mfrow=c(1,2))
plot(g1mut, vertex.label.size = .3, vertex.size = g1$degin/2, edge.arrow.size = 0,
     layout = lay)
plot(g1asy, vertex.label.size = .3, vertex.size = g1$degin/2, edge.arrow.size = .2,
     layout = lay)
dev.off()

#ego-networks des seeds
egog <- make_ego_graph(g, order = 1, V(g)$seed == 1)

list <- V(g)[seed == 1]$name

d <- NULL
i <- 1

for (i in 1:length(egog)){    #boucle qui a le nombre d'itérations correspondant à la longueur de la liste des ego
    nom <- list[i]                #identifiant
    #suppression d'ego
    egi <- delete.vertices(egog[[i]], V(egog[[i]])[name == nom]) 
    nbsommets <- vcount(egi)              #nombre de sommets
    nbliens <- ecount(egi)                #nb de liens
    densite <- graph.density(egi)         #densité
    comp <- components(egi)               # composantes connexes
    nbcomp <- comp$no                     #nb de composantes connexes
    sizecomp <- 100*comp$csize[[1]]/nbsommets #% de sommets dans la plus grande cc
    E(egi)$mut <- which_mutual(egi, es = E(egi))
    mut <- 100*length(E(egi)[mut == TRUE])/nbliens  # %de liens mutuels 
    transitivite <- transitivity(egi)
    d <- rbind(d, data.frame(nom, nbsommets,
                           nbliens, densite, nbcomp, sizecomp,mut,
                           transitivite)) 
    print(i)
}

#ego Venom, Lifelover et Cradle of Filth
egoV <- egog[[30]]
egoV <- delete.vertices(egoV, V(egoV)[name == 'Venom'])

egoL <- egog[[20]]
egoL <- delete.vertices(egoL, V(egoL)[name == 'Lifelover'])

egoC <- egog[[6]]
egoC <- delete.vertices(egoC, V(egoC)[name == 'Cradle of Filth'])

par(mfrow=c(1,3))
plot(egoV, vertex.label.cex = 1.5, edge.arrow.size = 0.2, vertex.size = 8,
     vertex.color = "yellow")
plot(egoL, vertex.label.cex = 1.5, edge.arrow.size = 0.2, vertex.size = 8,
     vertex.color = "yellow")
plot(egoC, vertex.label.cex = 1.5, edge.arrow.size = 0.2, vertex.size = 8,
     vertex.color = "yellow")
dev.off()
